@@ -420,7 +420,7 @@ ttestISClass <- R6::R6Class(
             else
                 table$setNote("hyp", NULL)
         },
-        .plot=function(image, ...) {
+        .plot=function(image, ggtheme, theme, ...) {
 
             if (is.null(image$state))
                 return(FALSE)
@@ -432,18 +432,12 @@ ttestISClass <- R6::R6Class(
             pd <- position_dodge(0.2)
 
             plot <- ggplot(data=image$state, aes(x=group, y=stat, shape=type)) +
-                geom_errorbar(aes(x=group, ymin=stat-cie, ymax=stat+cie, width=.1), size=.8, colour='#333333', position=pd) +
-                geom_point(aes(x=group, y=stat, colour=type, shape=type), fill='white', size=3, colour='#333333', position=pd) +
+                geom_errorbar(aes(x=group, ymin=stat-cie, ymax=stat+cie, width=.1), size=.8, colour=theme$color[2], position=pd) +
+                geom_point(aes(x=group, y=stat, shape=type), color=theme$color[1], fill=theme$fill[1], size=3, position=pd) +
                 labs(x=groupName, y=image$key) +
                 scale_shape_manual(name='', values=c(mean=21, median=22), labels=c(mean=paste0('Mean (', ciw, '% CI)'), median='Median')) +
-                theme(
-                    text=element_text(size=16, colour='#333333'),
-                    plot.background=element_rect(fill='transparent', color=NA),
-                    panel.background=element_rect(fill='#E8E8E8'),
-                    axis.text.x=element_text(margin=margin(5,0,0,0)),
-                    axis.text.y=element_text(margin=margin(0,5,0,0)),
-                    axis.title.x=element_text(margin=margin(10,0,0,0)),
-                    axis.title.y=element_text(margin=margin(0,10,0,0)))
+                ggtheme + theme(plot.title = ggplot2::element_text(margin=ggplot2::margin(b = 5.5 * 1.2)),
+                              plot.margin = ggplot2::margin(5.5, 5.5, 5.5, 5.5))
 
             suppressWarnings(print(plot))
 
